@@ -14,7 +14,7 @@ from social_auth.exceptions import AuthFailed, AuthMissingParameter
 
 
 # BrowserID verification server
-BROWSER_ID_SERVER = 'https://browserid.org/verify'
+BROWSER_ID_SERVER = 'https://verifier.login.persona.org/verify'
 
 
 class BrowserIDBackend(SocialAuthBackend):
@@ -31,7 +31,7 @@ class BrowserIDBackend(SocialAuthBackend):
         #  'audience': 'localhost:8000',
         #  'expires': 1328983575529,
         #  'email': 'name@server.com',
-        #  'issuer': 'browserid.org'}
+        #  'issuer': 'login.persona.org'}
         email = response['email']
         return {USERNAME: email.split('@', 1)[0],
                 'email': email,
