@@ -18,7 +18,7 @@ from urllib2 import Request, HTTPError
 from hashlib import md5
 
 from social_auth.backends import OAuthBackend, BaseOAuth2, USERNAME
-from social_auth.backends.exceptions import AuthCanceled
+from social_auth.exceptions import AuthCanceled
 from social_auth.utils import setting, log, dsa_urlopen
 
 MAILRU_API_URL = 'http://www.appsmail.ru/platform/api'
